<?php

namespace App\Http\Controllers\Api;

use App\Models\Favorite;
use App\Models\Notification;
use App\Models\Order;
use App\Models\Gift;
use App\Models\GiftDescription;
use App\Models\CityDescription;
use App\Models\City;
use App\User;
use Validator;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use Edujugon\PushNotification\PushNotification;


class OrderController extends Controller
{

    public function orders($lang, Request $request)
    {
        $orders = Order::where(['status' => 'active', 'poor_confirm' => 'not_active', 'rich_confirm' => 'not_active'])->get();

        if ($request->city_id && $request->gift_id) {
            $poors = User::where(['city_id' => $request->city_id, 'status' => 'active'])->pluck('id');
            $orders = Order::where(['status' => 'active', 'gift_id' => $request->gift_id, 'poor_confirm' => 'not_active', 'rich_confirm' => 'not_active'])->whereIn('poor_id', $poors)->get();
        } elseif ($request->city_id) {
            $poors = User::where(['city_id' => $request->city_id, 'status' => 'active'])->pluck('id');
            $orders = Order::where(['status' => 'active', 'poor_confirm' => 'not_active', 'rich_confirm' => 'not_active'])->whereIn('poor_id', $poors)->get();
        } elseif ($request->gift_id) {
            $orders = Order::where(['status' => 'active', 'gift_id' => $request->gift_id, 'poor_confirm' => 'not_active', 'rich_confirm' => 'not_active'])->get();
        }
        $data = [];
        foreach ($orders as $order) {
            $arr['id'] = (string)$order->id;
            if ($order->poor_id == null) {
                $arr['poor_id'] = "";
            } else {
                $arr['poor_id'] = (string)$order->poor_id;
            }
            $poor = User::where('id', $order->poor_id)->first();
            $arr['poor_name'] = $poor->name;
            $arr['poor_mobile'] = $poor->mobile;
            $city = City::where('id', $poor->city_id)->first();
            if ($lang == 'ar') {
                $arr['poor_city'] = CityDescription::where(['city_id' => $city->id, 'language_id' => 1])->value('name');
            } elseif ($lang == 'en') {
                $arr['poor_city'] = CityDescription::where(['city_id' => $city->id, 'language_id' => 2])->value('name');
            }
            if ($order->rich_id == null) {
                $arr['rich_id'] = "";
            } else {
                $arr['rich_id'] = (string)$order->rich_id;
            }
            $arr['gift_id'] = (string)$order->gift_id;
            if ($lang == 'ar') {
                $arr['gift_name'] = GiftDescription::where(['gift_id' => $order->gift_id, 'language_id' => 1])->value('name');
            } elseif ($lang == 'en') {
                $arr['gift_name'] = GiftDescription::where(['gift_id' => $order->gift_id, 'language_id' => 2])->value('name');

            }
            $image = Gift::where(['id' => $order->gift_id])->value('image');
            $arr['gift_image'] = asset('images/gifts/' . $image);

            $arr['description'] = $order->description;
            if ($order->poor_confirm == null) {
                $arr['poor_confirm'] = "";
            } else {
                $arr['poor_confirm'] = $order->poor_confirm;
            }
            if ($order->poor_confirm == null) {
                $arr['rich_confirm'] = "";
            } else {
                $arr['rich_confirm'] = $order->rich_confirm;
            }
            //favourite =  true or false
            if ($request->user_id) {
                $found = Favorite::where(['user_id' => $request->user_id, 'order_id' => $order->id])->first();
                if ($found) {
                    $arr['favorite'] = true;
                } else {
                    $arr['favorite'] = false;
                }
            } else {
                $arr['favorite'] = false;
            }


            $data[] = $arr;
        }

        return response()->json(['value' => true, 'data' => $data]);

    }

    public function create_order(Request $request)
    {

        $create_order = new Order;
        $create_order->poor_id = $request->poor_id;
        $create_order->gift_id = $request->gift_id;
        $create_order->poor_confirm = "not_active";
        $create_order->rich_confirm = "not_active";
        $create_order->status = "active";
        $create_order->description = $request->description;

        $create_order->save();
        $arr['id'] = (string)$create_order->id;
        $arr['poor_id'] = (string)$create_order->poor_id;
        $arr['rich_id'] = "";
        $arr['gift_id'] = (string)$create_order->gift_id;
        $arr['description'] = $create_order->description;


        return response()->json(['value' => true, 'data' => $arr]);

    }

    public function rich_confirm(Request $request)
    {
        $rich_confirm = Order::find($request->order_id);
        if (!$rich_confirm) {
            return response()->json(['value' => false, 'msg' => 'order not found']);
        }
        $rich_confirm->rich_confirm = "active";
        $rich_confirm->update();
        $arr['id'] = (string)$rich_confirm->id;
        $arr['poor_id'] = (string)$rich_confirm->poor_id;
        $arr['rich_id'] = (string)$rich_confirm->rich_id;
        $arr['gift_id'] = (string)$rich_confirm->gift_id;
        $arr['description'] = $rich_confirm->description;
        if ($rich_confirm->poor_confirm == null) {
            $arr['poor_confirm'] = "";
        } else {
            $arr['poor_confirm'] = (string)$rich_confirm->poor_confirm;
        }
        $arr['rich_confirm'] = (string)$rich_confirm->rich_confirm;

        return response()->json(['value' => true, 'data' => $arr]);
    }

    public function poor_confirm(Request $request,$lang)
    {
        $notification = Notification::where(['id' => $request->notification_id])->first();
        $poor_confirm = Order::find($notification->order_id);
        if (!$poor_confirm) {
            return response()->json(['value' => false, 'msg' => 'order not found']);
        }
        $poor_confirm->poor_confirm = "active";
        $poor_confirm->update();
        $donation=$poor_confirm;
        $rich = User::find($donation->rich_id);
        $poor = User::find($donation->poor_id);
        $gift = Gift::find($donation->gift_id);
        $gift_name = GiftDescription::where(['language_id' => 1, 'gift_id' => $gift->id])->value('name');

        $push = new PushNotification('fcm');
        $msg = [
            'notification' => [
                'title' => 'تاكيد اتمام احتياج',
                'sound' => 'default',

            ],
            'data' => [
                'title' => 'تاكيد اتمام احتياج',
                'message' => 'تاكيد اتمام احتياج ' . $gift_name . ' الخاص بك من قبل ' . $poor->name . ' ',
                'order_id' => $donation->id,
            ],
            'priority' => 'normal',
        ];
        $push->setMessage($msg)
            ->setDevicesToken($rich->device_token)
            ->send();
        $notification->delete();
        $notification = new Notification;
        $notification->sender_id = $poor->id;
        $notification->receiver_id = $rich->id;
        $notification->order_id = $donation->id;
        $notification->title = 'تاكيد اتمام احتياج ' . $gift_name . ' الخاص بك من قبل ' . $poor->name . ' ';
        $notification->save();

        $arr['id'] = (string)$poor_confirm->id;
        $arr['poor_id'] = (string)$poor_confirm->poor_id;
        $arr['rich_id'] = (string)$poor_confirm->rich_id;
        $arr['gift_id'] = (string)$poor_confirm->gift_id;
        $arr['description'] = $poor_confirm->description;
        $arr['poor_confirm'] = (string)$poor_confirm->poor_confirm;
        $arr['rich_confirm'] = (string)$poor_confirm->rich_confirm;

        return response()->json(['value' => true, 'data' => $arr]);
    }

    public function add_donation($lang, Request $request)
    {

        if (!$request->rich_id || !$request->order_id) {
            $lang == 'ar' ? $msg = 'توجد مشكله بالبيانات المدخلة' : $msg = 'rich_id or order_id not found';
            return response()->json(['value' => false, 'msg' => $msg]);
        }
        // $is_donate=Order::where(['id'=>$request->order_id,'rich_id'=>$request->rich_id,'rich_confirm'=>'active'])->first();
        // if($is_donate){
        //     $lang=='ar' ? $msg='تم الاضافة من قبل': $msg='added already' ;
        //     return response()->json(['value' => false, 'msg' => $msg]);
        // }
        $donation = Order::find($request->order_id);
        $donation->rich_id = $request->rich_id;
        $donation->rich_confirm = 'active';
        $donation->update();

        $rich = User::find($donation->rich_id);
        $poor = User::find($donation->poor_id);
        $gift = Gift::find($donation->gift_id);
        $gift_name = GiftDescription::where(['language_id' => 1, 'gift_id' => $gift->id])->value('name');


        $push = new PushNotification('fcm');
        $msg = [
                'notification' => [
                    'title' => 'تاكيد اتمام احتياج',
                    'sound' => 'default',

                ],
                'data' => [
                    'title' => 'تاكيد اتمام احتياج',
                    'message' => 'تاكيد اتمام احتياج ' . $gift_name . ' الخاص بك من قبل ' . $rich->name . ' ',
                    'order_id' => $donation->id,
                ],
                'priority' => 'normal',
            ];
        $push->setMessage($msg)
            ->setDevicesToken($poor->device_token)
            ->send();

        $notification = new Notification;
        $notification->sender_id = $rich->id;
        $notification->receiver_id = $poor->id;
        $notification->order_id = $donation->id;
        $notification->title = 'تاكيد اتمام احتياج ' . $gift_name . ' الخاص بك من قبل ' . $rich->name . ' ';
        $notification->save();

        $arr['id'] = $donation->id;
        $arr['poor_id'] = (string)$donation->poor_id;
        $poor_name = User::where('id', $donation->poor_id)->value('name');
        $arr['poor_name'] = $poor_name;
        $poor_mobile = User::where('id', $donation->poor_id)->value('mobile');
        $arr['poor_mobile'] = $poor_mobile;
        $poor_city = User::where('id', $donation->poor_id)->value('city_id');
        if ($lang == 'ar') {
            $city_name = CityDescription::where(['city_id' => $poor_city, 'language_id' => 1])->value('name');
        } elseif ($lang == 'en') {
            $city_name = CityDescription::where(['city_id' => $poor_city, 'language_id' => 2])->value('name');
        }
        $arr['city_name'] = $city_name;
        $arr['rich_id'] = (string)$donation->rich_id;

        $favourite = Favorite::where(['user_id' => $donation->rich_id, 'order_id' => $donation->id])->get();

        if ($favourite) {
            $arr['favourite'] = true;
        } else {
            $arr['favourite'] = false;
        }

        if ($lang == 'ar') {
            $gift_name = GiftDescription::where(['gift_id' => $donation->gift_id, 'language_id' => 1])->value('name');
        } elseif ($lang == 'en') {
            $gift_name = GiftDescription::where(['gift_id' => $donation->gift_id, 'language_id' => 2])->value('name');
        }
        $arr['gift_name'] = $gift_name;
        $arr['description'] = $donation->description;
        $arr['poor_confirm'] = $donation->poor_confirm;
        $arr['rich_confirm'] = $donation->rich_confirm;
        return response()->json(['value' => true, 'data' => $arr]);
    }

    public function my_donations($lang, Request $request)
    {
        if (!$request->rich_id) {
            return response()->json(['value' => false, 'msg' => 'rich_id not found']);
        }
        $my_donations = Order::where(['rich_id' => $request->rich_id, 'poor_confirm' => 'active', 'rich_confirm' => 'active'])->get();
        $data = [];
        foreach ($my_donations as $donation) {
            $arr['id'] = $donation->id;
            $arr['poor_id'] = (string)$donation->poor_id;
            $poor_name = User::where('id', $donation->poor_id)->value('name');
            $arr['poor_name'] = $poor_name;
            $poor_mobile = User::where('id', $donation->poor_id)->value('mobile');
            $arr['poor_mobile'] = $poor_mobile;
            $poor_city = User::where('id', $donation->poor_id)->value('city_id');
            if ($lang == 'ar') {
                $city_name = CityDescription::where(['city_id' => $poor_city, 'language_id' => 1])->value('name');
            } elseif ($lang == 'en') {
                $city_name = CityDescription::where(['city_id' => $poor_city, 'language_id' => 2])->value('name');
            }
            $arr['city_name'] = $city_name;
            $arr['rich_id'] = (string)$donation->rich_id;
            $favourite = Favorite::where(['user_id' => $donation->rich_id, 'order_id' => $donation->id])->get();
            if ($favourite) {
                $arr['favourite'] = true;
            } else {
                $arr['favourite'] = false;
            }
            if ($lang == 'ar') {
                $gift_name = GiftDescription::where(['gift_id' => $donation->gift_id, 'language_id' => 1])->value('name');
            } elseif ($lang == 'en') {
                $gift_name = GiftDescription::where(['gift_id' => $donation->gift_id, 'language_id' => 2])->value('name');
            }
            $arr['gift_name'] = $gift_name;
            $arr['description'] = $donation->description;
            $arr['poor_confirm'] = $donation->poor_confirm;
            $arr['rich_confirm'] = $donation->rich_confirm;
            $data[] = $arr;
        }
        return response()->json(['value' => true, 'data' => $data]);
    }

    public function cancel_order(Request $request)
    {

        if (!$request->poor_id && !$request->order_id) {

            return response()->json(['value' => false, 'msg' => 'poor_id or order_id not found']);
        }

        $my_order = Order::where(['poor_id' => $request->poor_id, 'id' => $request->order_id])->first();
        if (!$my_order) {
            return response()->json(['value' => false, 'msg' => 'order not found']);
        } else {
            $my_order->delete();
            return response()->json(['value' => true]);
        }
    }

    public function my_notification(Request $request,$lang)
    {

        if (!$request->receiver_id) {
            return response()->json(['value' => false, 'msg' => 'receiver_id not found']);
        }
        $my_notification = Notification::where('receiver_id', $request->receiver_id)->get();
        $data = [];
        foreach ($my_notification as $item_notification) {

            $arr['id'] = $item_notification->id;
            $sender=User::find($item_notification->sender_id);
            $arr_s['id']=$item_notification->sender_id;
            $arr_s['name']=$sender->name;
            $arr['sender'] = $arr_s;
            $receiver=User::find($item_notification->receiver_id);
            $arr_r['id']=$item_notification->receiver_id;
            $arr_r['name']=$receiver->name;
            $arr['receiver'] = $arr_r;
            $arr['message']=$item_notification->title;
            $arr['read'] = $item_notification->read;
           

            $data[] = $arr;
        }
        return response()->json(['value' => true, 'data' => $data]);
    }

    public function poor_refuse(Request $request,$lang)
    {
        $poor_refuse = Notification::where(['id' => $request->notification_id, 'receiver_id' => $request->receiver_id])->first();
        $poor_refuse->read = '1';
        $poor_refuse->update();

        $arr['id'] = $poor_refuse->id;
        
        $sender=User::find($poor_refuse->sender_id);
        $arr_s['id']=$poor_refuse->sender_id;
        $arr_s['name']=$sender->name;
        $arr['sender'] = $arr_s;
        $receiver=User::find($poor_refuse->receiver_id);
        $arr_r['id']=$poor_refuse->receiver_id;
        $arr_r['name']=$receiver->name;
        $arr['receiver'] = $arr_r;
        $order=Order::find($poor_refuse->order_id);
        
            $arr_o['id'] = (string)$order->id;
            if ($order->poor_id == null) {
                $arr_o['poor_id'] = "";
            } else {
                $arr_o['poor_id'] = (string)$order->poor_id;
            }
            $poor = User::where('id', $order->poor_id)->first();
            $arr_o['poor_name'] = $poor->name;
            $arr_o['poor_mobile'] = $poor->mobile;
            $city = City::where('id', $poor->city_id)->first();
            if ($lang == 'ar') {
                $arr_o['poor_city'] = CityDescription::where(['city_id' => $city->id, 'language_id' => 1])->value('name');
            } elseif ($lang == 'en') {
                $arr_o['poor_city'] = CityDescription::where(['city_id' => $city->id, 'language_id' => 2])->value('name');
            }
            if ($order->rich_id == null) {
                $arr_o['rich_id'] = "";
            } else {
                $arr_o['rich_id'] = (string)$order->rich_id;
            }
            $arr['gift_id'] = (string)$order->gift_id;
            if ($lang == 'ar') {
                $arr_o['gift_name'] = GiftDescription::where(['gift_id' => $order->gift_id, 'language_id' => 1])->value('name');
            } elseif ($lang == 'en') {
                $arr_o['gift_name'] = GiftDescription::where(['gift_id' => $order->gift_id, 'language_id' => 2])->value('name');

            }
            $image = Gift::where(['id' => $order->gift_id])->value('image');
            $arr_o['gift_image'] = asset('images/gifts/' . $image);

            $arr_o['description'] = $order->description;
            if ($order->poor_confirm == null) {
                $arr_o['poor_confirm'] = "";
            } else {
                $arr_o['poor_confirm'] = $order->poor_confirm;
            }
            if ($order->poor_confirm == null) {
                $arr_o['rich_confirm'] = "";
            } else {
                $arr_o['rich_confirm'] = $order->rich_confirm;
            }
            //favourite =  true or false
            if ($request->user_id) {
                $found = Favorite::where(['user_id' => $request->user_id, 'order_id' => $order->id])->first();
                if ($found) {
                    $arr_o['favorite'] = true;
                } else {
                    $arr_o['favorite'] = false;
                }
            } else {
                $arr_o['favorite'] = false;
            }
        
        $arr['read'] = $poor_refuse->read;
        $arr['order'] = $arr_o;
        $arr['title'] = $poor_refuse->title;

        return response()->json(['value' => true, 'data' => $arr]);

    }

}
